diff --git a/ext_tests/src/com/android/launcher3/testing/DebugTestInformationHandler.java b/ext_tests/src/com/android/launcher3/testing/DebugTestInformationHandler.java
index bdac88a043..a645e58ecc 100644
--- a/ext_tests/src/com/android/launcher3/testing/DebugTestInformationHandler.java
+++ b/ext_tests/src/com/android/launcher3/testing/DebugTestInformationHandler.java
@@ -210,12 +210,19 @@ public class DebugTestInformationHandler extends TestInformationHandler {
}
case TestProtocol.REQUEST_USE_TEST_WORKSPACE_LAYOUT: {
- useTestWorkspaceLayout(true);
+ useTestWorkspaceLayout(
+ LauncherSettings.Settings.ARG_DEFAULT_WORKSPACE_LAYOUT_TEST);
+ return response;
+ }
+
+ case TestProtocol.REQUEST_USE_TEST2_WORKSPACE_LAYOUT: {
+ useTestWorkspaceLayout(
+ LauncherSettings.Settings.ARG_DEFAULT_WORKSPACE_LAYOUT_TEST2);
return response;
}
case TestProtocol.REQUEST_USE_DEFAULT_WORKSPACE_LAYOUT: {
- useTestWorkspaceLayout(false);
+ useTestWorkspaceLayout(null);
return response;
}
@@ -257,12 +264,17 @@ public class DebugTestInformationHandler extends TestInformationHandler {
}
}
- private void useTestWorkspaceLayout(boolean useTestWorkspaceLayout) {
+ private void useTestWorkspaceLayout(String layout) {
final long identity = Binder.clearCallingIdentity();
try {
- LauncherSettings.Settings.call(mContext.getContentResolver(), useTestWorkspaceLayout
- ? LauncherSettings.Settings.METHOD_SET_USE_TEST_WORKSPACE_LAYOUT_FLAG
- : LauncherSettings.Settings.METHOD_CLEAR_USE_TEST_WORKSPACE_LAYOUT_FLAG);
+ if (layout != null) {
+ LauncherSettings.Settings.call(mContext.getContentResolver(),
+ LauncherSettings.Settings.METHOD_SET_USE_TEST_WORKSPACE_LAYOUT_FLAG,
+ layout);
+ } else {
+ LauncherSettings.Settings.call(mContext.getContentResolver(),
+ LauncherSettings.Settings.METHOD_CLEAR_USE_TEST_WORKSPACE_LAYOUT_FLAG);
+ }
} finally {
Binder.restoreCallingIdentity(identity);
}
diff --git a/protos/launcher_atom.proto b/protos/launcher_atom.proto
index 151ec5a93c..677c9921a0 100644
--- a/protos/launcher_atom.proto
+++ b/protos/launcher_atom.proto
@@ -130,7 +130,7 @@ message TaskBarContainer {
optional int32 cardinality = 2;
}
-// Next value 40
+// Next value 41
enum Attribute {
UNKNOWN = 0;
DEFAULT_LAYOUT = 1; // icon automatically placed in workspace, folder, hotseat
@@ -186,6 +186,7 @@ enum Attribute {
WEB_SEARCH_RESULT_PERSONAL = 36;
WEB_SEARCH_RESULT_CALCULATOR = 37;
WEB_SEARCH_RESULT_URL = 38;
+ WEB_SEARCH_RESULT_RICH_ANSWER = 40;
WIDGETS_BOTTOM_TRAY = 28;
WIDGETS_TRAY_PREDICTION = 29;
diff --git a/quickstep/res/layout/taskbar_all_apps.xml b/quickstep/res/layout/taskbar_all_apps.xml
index c7679beb23..976cd9e2a7 100644
--- a/quickstep/res/layout/taskbar_all_apps.xml
+++ b/quickstep/res/layout/taskbar_all_apps.xml
@@ -27,40 +27,5 @@
android:clipChildren="true"
android:clipToPadding="false"
android:focusable="false"
- android:saveEnabled="false"
- android:theme="?attr/allAppsTheme">
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+ android:saveEnabled="false" />
diff --git a/quickstep/res/values-az/strings.xml b/quickstep/res/values-az/strings.xml
index 1a63592cb3..e844ec1ef9 100644
--- a/quickstep/res/values-az/strings.xml
+++ b/quickstep/res/values-az/strings.xml
@@ -95,12 +95,9 @@
"Tapşırıq panelində təhsil"
"Tapşırıq panelindəki təlim bölməsi görünür"
"Tapşırıq panelindəki təlim bölməsi bağlanıb"
-
-
-
-
-
-
+ "Eyni anda 2 tətbiqi istifadə etmək üçün yan tərəfə çəkin"
+ "Tapşırıq panelini göstərmək üçün azca yuxarı sürüşdürün"
+ "Tapşırıq paneli rejiminizə əsasən tətbiqlər təklif edir"
"Sonra"
"Geri"
"Bağlayın"
diff --git a/quickstep/res/values-bs/strings.xml b/quickstep/res/values-bs/strings.xml
index 32b98c9f38..8b1640d4ff 100644
--- a/quickstep/res/values-bs/strings.xml
+++ b/quickstep/res/values-bs/strings.xml
@@ -95,12 +95,9 @@
"Edukacija o traci zadataka"
"Edukacija o programskoj traci je prikazana"
"Edukacija o programskoj traci je zatvorena"
-
-
-
-
-
-
+ "Povucite u stranu za istovremeno korištenje 2 aplikacije"
+ "Kratki pokret prema gore za prikaz trake sa zadacima"
+ "Traka sa zadacima predlaže aplikacije na temelju vaše rutine"
"Naprijed"
"Nazad"
"Zatvori"
diff --git a/quickstep/res/values-el/strings.xml b/quickstep/res/values-el/strings.xml
index fc8e7b004d..807ce43174 100644
--- a/quickstep/res/values-el/strings.xml
+++ b/quickstep/res/values-el/strings.xml
@@ -95,12 +95,9 @@
"Πληροφορίες χρήσης της Γραμμής εργαλείων"
"Η εκπαίδευση για τη γραμμή εργασιών εμφανίστηκε"
"Η εκπαίδευση για τη γραμμή εργασιών έκλεισε"
-
-
-
-
-
-
+ "Σύρετε στο πλάι για ταυτόχρονη χρήση δύο εφαρμογών"
+ "Σύρετε σύντομα προς τα πάνω για εμφάνιση γραμμής εργαλείων"
+ "Η γραμμή εργαλείων συνιστά εφαρμογές βάσει της ρουτίνας σας"
"Επόμενο"
"Πίσω"
"Κλείσιμο"
diff --git a/quickstep/res/values-en-rAU/strings.xml b/quickstep/res/values-en-rAU/strings.xml
index c5daa61ac9..414593ab62 100644
--- a/quickstep/res/values-en-rAU/strings.xml
+++ b/quickstep/res/values-en-rAU/strings.xml
@@ -95,12 +95,9 @@
"Taskbar education"
"Taskbar education appeared"
"Taskbar education closed"
-
-
-
-
-
-
+ "Drag to the side to use two apps at once"
+ "Short swipe up to show the taskbar"
+ "The taskbar suggests apps based on your routine"
"Next"
"Back"
"Close"
diff --git a/quickstep/res/values-en-rCA/strings.xml b/quickstep/res/values-en-rCA/strings.xml
index 4ab5fa3da6..41fb803fc8 100644
--- a/quickstep/res/values-en-rCA/strings.xml
+++ b/quickstep/res/values-en-rCA/strings.xml
@@ -95,12 +95,9 @@
"Taskbar education"
"Taskbar education appeared"
"Taskbar education closed"
-
-
-
-
-
-
+ "Drag to the side to use 2 apps at once"
+ "Short swipe up to show the taskbar"
+ "The taskbar suggests apps based on your routine"
"Next"
"Back"
"Close"
diff --git a/quickstep/res/values-en-rGB/strings.xml b/quickstep/res/values-en-rGB/strings.xml
index c5daa61ac9..414593ab62 100644
--- a/quickstep/res/values-en-rGB/strings.xml
+++ b/quickstep/res/values-en-rGB/strings.xml
@@ -95,12 +95,9 @@
"Taskbar education"
"Taskbar education appeared"
"Taskbar education closed"
-
-
-
-
-
-
+ "Drag to the side to use two apps at once"
+ "Short swipe up to show the taskbar"
+ "The taskbar suggests apps based on your routine"
"Next"
"Back"
"Close"
diff --git a/quickstep/res/values-en-rIN/strings.xml b/quickstep/res/values-en-rIN/strings.xml
index c5daa61ac9..414593ab62 100644
--- a/quickstep/res/values-en-rIN/strings.xml
+++ b/quickstep/res/values-en-rIN/strings.xml
@@ -95,12 +95,9 @@
"Taskbar education"
"Taskbar education appeared"
"Taskbar education closed"
-
-
-
-
-
-
+ "Drag to the side to use two apps at once"
+ "Short swipe up to show the taskbar"
+ "The taskbar suggests apps based on your routine"
"Next"
"Back"
"Close"
diff --git a/quickstep/res/values-en-rXC/strings.xml b/quickstep/res/values-en-rXC/strings.xml
index 5d169df83b..45ce0c1b67 100644
--- a/quickstep/res/values-en-rXC/strings.xml
+++ b/quickstep/res/values-en-rXC/strings.xml
@@ -95,12 +95,9 @@
"Taskbar education"
"Taskbar education appeared"
"Taskbar education closed"
-
-
-
-
-
-
+ "Drag to the side to use 2 apps at once"
+ "Short swipe up to show the taskbar"
+ "The taskbar suggests apps based on your routine"
"Next"
"Back"
"Close"
diff --git a/quickstep/res/values-hr/strings.xml b/quickstep/res/values-hr/strings.xml
index 326e499b2f..dd7de8cbbc 100644
--- a/quickstep/res/values-hr/strings.xml
+++ b/quickstep/res/values-hr/strings.xml
@@ -95,12 +95,9 @@
"Upute za traku sa zadacima"
"Upute za programsku traku su se pojavile"
"Upute za programsku traku su zatvorene"
-
-
-
-
-
-
+ "Povucite u stranu za istovremeno korištenje 2 aplikacije"
+ "Kratki pokret prema gore za prikaz trake sa zadacima"
+ "Traka sa zadacima predlaže aplikacije na temelju vaše rutine"
"Dalje"
"Natrag"
"Zatvori"
diff --git a/quickstep/res/values-ne/strings.xml b/quickstep/res/values-ne/strings.xml
index 9ba1bd013f..5c34ef4c39 100644
--- a/quickstep/res/values-ne/strings.xml
+++ b/quickstep/res/values-ne/strings.xml
@@ -78,10 +78,8 @@
"सबै तयार भयो!"
"होममा जान माथितिर स्वाइप गर्नुहोस्"
"आफ्नो होम स्क्रिनमा जान होम बटनमा ट्याप गर्नुहोस्"
-
-
-
-
+ "तपाईं अब आफ्नो %1$s चलाउन थाल्न सक्नुहुन्छ"
+ "डिभाइस"
"सिस्टम नेभिगेसनसम्बन्धी सेटिङ"
"सेयर गर्नुहोस्"
"स्क्रिनसट"
@@ -94,8 +92,7 @@
"रद्द गर्नुहोस्"
"स्किप गर्नु…"
"स्क्रिन घुमाउनुहोस्"
-
-
+ "टास्कबार एजुकेसन"
"टास्कबार एजुकेसन देखिएको छ"
"टास्कबार एजुकेसन बन्द गरिएको छ"
@@ -115,10 +112,8 @@
"हालसालैका बटनहरू"
"सूचनाहरू"
"द्रुत सेटिङ"
-
-
-
-
+ "टास्कबार"
+ "नेभिगेसन बार"
"सिरान/बायाँतिर सार्नुहोस्"
"फेद/दायाँतिर सार्नुहोस्"
diff --git a/quickstep/res/values-pt/strings.xml b/quickstep/res/values-pt/strings.xml
index b0d6499100..fbd5b782b8 100644
--- a/quickstep/res/values-pt/strings.xml
+++ b/quickstep/res/values-pt/strings.xml
@@ -95,12 +95,9 @@
"Informações sobre a barra de tarefas"
"As dicas sobre a barra de tarefas foram abertas"
"As dicas sobre a barra de tarefas foram fechadas"
-
-
-
-
-
-
+ "Arraste para o lado para usar dois apps ao mesmo tempo"
+ "Deslize para cima para mostrar a barra de tarefas"
+ "A barra de tarefas sugere apps com base na sua rotina"
"Próxima"
"Voltar"
"Fechar"
diff --git a/quickstep/src/com/android/launcher3/taskbar/TaskbarActivityContext.java b/quickstep/src/com/android/launcher3/taskbar/TaskbarActivityContext.java
index 35fe4c4fac..997d46ec90 100644
--- a/quickstep/src/com/android/launcher3/taskbar/TaskbarActivityContext.java
+++ b/quickstep/src/com/android/launcher3/taskbar/TaskbarActivityContext.java
@@ -271,14 +271,13 @@ public class TaskbarActivityContext extends BaseTaskbarContext {
}
private void updateIconSize(Resources resources) {
- float taskbarIconSize = resources.getDimension(DisplayController.isTransientTaskbar(this)
- ? mDeviceProfile.isTwoPanels
- ? R.dimen.transient_taskbar_two_panels_icon_size
- : R.dimen.transient_taskbar_icon_size
- : R.dimen.taskbar_icon_size);
- mDeviceProfile.updateIconSize(1, resources);
- float iconScale = taskbarIconSize / mDeviceProfile.iconSizePx;
- mDeviceProfile.updateIconSize(iconScale, resources);
+ mDeviceProfile.iconSizePx = resources.getDimensionPixelSize(
+ DisplayController.isTransientTaskbar(this)
+ ? mDeviceProfile.isTwoPanels
+ ? R.dimen.transient_taskbar_two_panels_icon_size
+ : R.dimen.transient_taskbar_icon_size
+ : R.dimen.taskbar_icon_size);
+ mDeviceProfile.updateIconSize(1f, resources);
}
/**
diff --git a/quickstep/src/com/android/launcher3/taskbar/allapps/TaskbarAllAppsContainerView.java b/quickstep/src/com/android/launcher3/taskbar/allapps/TaskbarAllAppsContainerView.java
index 70405d94cb..eeca329e80 100644
--- a/quickstep/src/com/android/launcher3/taskbar/allapps/TaskbarAllAppsContainerView.java
+++ b/quickstep/src/com/android/launcher3/taskbar/allapps/TaskbarAllAppsContainerView.java
@@ -17,6 +17,7 @@ package com.android.launcher3.taskbar.allapps;
import android.content.Context;
import android.util.AttributeSet;
+import android.view.View;
import android.view.WindowInsets;
import com.android.launcher3.DeviceProfile;
@@ -42,6 +43,19 @@ public class TaskbarAllAppsContainerView extends
return super.onApplyWindowInsets(insets);
}
+ @Override
+ protected View inflateSearchBox() {
+ // Remove top padding of header, since we do not have any search
+ mHeader.setPadding(mHeader.getPaddingLeft(), 0,
+ mHeader.getPaddingRight(), mHeader.getPaddingBottom());
+
+ TaskbarAllAppsFallbackSearchContainer searchView =
+ new TaskbarAllAppsFallbackSearchContainer(getContext(), null);
+ searchView.setId(R.id.search_container_all_apps);
+ searchView.setVisibility(GONE);
+ return searchView;
+ }
+
@Override
protected boolean isSearchSupported() {
return false;
@@ -53,4 +67,10 @@ public class TaskbarAllAppsContainerView extends
// TODO(b/240670050): Remove this and add header protection for the taskbar entrypoint.
mBottomSheetBackground.setBackgroundResource(R.drawable.bg_rounded_corner_bottom_sheet);
}
+
+ @Override
+ public boolean isInAllApps() {
+ // All apps is always open
+ return true;
+ }
}
diff --git a/quickstep/src/com/android/launcher3/taskbar/overlay/TaskbarOverlayContext.java b/quickstep/src/com/android/launcher3/taskbar/overlay/TaskbarOverlayContext.java
index ebaf60a10f..38b6dfd39b 100644
--- a/quickstep/src/com/android/launcher3/taskbar/overlay/TaskbarOverlayContext.java
+++ b/quickstep/src/com/android/launcher3/taskbar/overlay/TaskbarOverlayContext.java
@@ -21,9 +21,6 @@ import android.view.View;
import com.android.launcher3.DeviceProfile;
import com.android.launcher3.LauncherPrefs;
import com.android.launcher3.R;
-import com.android.launcher3.allapps.ActivityAllAppsContainerView;
-import com.android.launcher3.allapps.search.DefaultSearchAdapterProvider;
-import com.android.launcher3.allapps.search.SearchAdapterProvider;
import com.android.launcher3.dot.DotInfo;
import com.android.launcher3.model.data.ItemInfo;
import com.android.launcher3.popup.PopupDataProvider;
@@ -137,10 +134,4 @@ public class TaskbarOverlayContext extends BaseTaskbarContext {
@Override
public void onPopupVisibilityChanged(boolean isVisible) {}
-
- @Override
- public SearchAdapterProvider> createSearchAdapterProvider(
- ActivityAllAppsContainerView> appsView) {
- return new DefaultSearchAdapterProvider(this);
- }
}
diff --git a/quickstep/src/com/android/quickstep/views/FloatingTaskView.java b/quickstep/src/com/android/quickstep/views/FloatingTaskView.java
index 1d421b2081..75a8ea2b3b 100644
--- a/quickstep/src/com/android/quickstep/views/FloatingTaskView.java
+++ b/quickstep/src/com/android/quickstep/views/FloatingTaskView.java
@@ -28,6 +28,7 @@ import com.android.launcher3.R;
import com.android.launcher3.Utilities;
import com.android.launcher3.anim.PendingAnimation;
import com.android.launcher3.statemanager.StatefulActivity;
+import com.android.launcher3.taskbar.TaskbarActivityContext;
import com.android.launcher3.touch.PagedOrientationHandler;
import com.android.launcher3.util.SplitConfigurationOptions;
import com.android.launcher3.views.BaseDragLayer;
@@ -85,6 +86,7 @@ public class FloatingTaskView extends FrameLayout {
private PagedOrientationHandler mOrientationHandler;
@SplitConfigurationOptions.StagePosition
private int mStagePosition;
+ private final Rect mTmpRect = new Rect();
public FloatingTaskView(Context context) {
this(context, null);
@@ -158,10 +160,24 @@ public class FloatingTaskView extends FrameLayout {
}
public void updateInitialPositionForView(View originalView) {
- Rect viewBounds = new Rect(0, 0, originalView.getWidth(), originalView.getHeight());
- Utilities.getBoundsForViewInDragLayer(mActivity.getDragLayer(), originalView, viewBounds,
- false /* ignoreTransform */, null /* recycle */,
- mStartingPosition);
+ if (originalView.getContext() instanceof TaskbarActivityContext) {
+ // If original View is a button on the Taskbar, find the on-screen bounds and calculate
+ // the equivalent bounds in the DragLayer, so we can set the initial position of
+ // this FloatingTaskView and start the split animation at the correct spot.
+ originalView.getBoundsOnScreen(mTmpRect);
+ mStartingPosition.set(mTmpRect);
+ int[] dragLayerPositionRelativeToScreen =
+ mActivity.getDragLayer().getLocationOnScreen();
+ mStartingPosition.offset(
+ -dragLayerPositionRelativeToScreen[0],
+ -dragLayerPositionRelativeToScreen[1]);
+ } else {
+ Rect viewBounds = new Rect(0, 0, originalView.getWidth(), originalView.getHeight());
+ Utilities.getBoundsForViewInDragLayer(mActivity.getDragLayer(), originalView,
+ viewBounds, false /* ignoreTransform */, null /* recycle */,
+ mStartingPosition);
+ }
+
final BaseDragLayer.LayoutParams lp = new BaseDragLayer.LayoutParams(
Math.round(mStartingPosition.width()),
Math.round(mStartingPosition.height()));
diff --git a/res/color-night-v31/widgets_picker_scrim.xml b/res/color-night-v31/widgets_picker_scrim.xml
deleted file mode 100644
index be7010b80b..0000000000
--- a/res/color-night-v31/widgets_picker_scrim.xml
+++ /dev/null
@@ -1,22 +0,0 @@
-
-
-
-
-
diff --git a/res/color-v31/widgets_picker_scrim.xml b/res/color-v31/widgets_picker_scrim.xml
deleted file mode 100644
index 648824ac1e..0000000000
--- a/res/color-v31/widgets_picker_scrim.xml
+++ /dev/null
@@ -1,22 +0,0 @@
-
-
-
-
-
diff --git a/res/color/widgets_picker_scrim.xml b/res/color/widgets_picker_scrim.xml
index 1cf97f61f7..5d5130086a 100644
--- a/res/color/widgets_picker_scrim.xml
+++ b/res/color/widgets_picker_scrim.xml
@@ -18,5 +18,5 @@
*/
-->
-
+
diff --git a/res/drawable/bg_all_apps_searchbox.xml b/res/drawable/bg_all_apps_searchbox.xml
index c3249279af..3c321e4c49 100644
--- a/res/drawable/bg_all_apps_searchbox.xml
+++ b/res/drawable/bg_all_apps_searchbox.xml
@@ -15,5 +15,6 @@
-->
-
+
+
\ No newline at end of file
diff --git a/res/layout/all_apps.xml b/res/layout/all_apps.xml
index f8a871a502..655c75d1b5 100644
--- a/res/layout/all_apps.xml
+++ b/res/layout/all_apps.xml
@@ -17,13 +17,9 @@
will bake the left/right padding into that view's background itself. -->
-
-
-
\ No newline at end of file
+ android:saveEnabled="false" />
\ No newline at end of file
diff --git a/res/layout/all_apps_content.xml b/res/layout/all_apps_content.xml
index 773ab8d4d3..925f4d963b 100644
--- a/res/layout/all_apps_content.xml
+++ b/res/layout/all_apps_content.xml
@@ -34,6 +34,7 @@
android:layout_width="match_parent"
android:layout_height="wrap_content"
android:clipToPadding="false"
+ android:layout_below="@id/search_container_all_apps"
android:paddingTop="@dimen/all_apps_header_top_padding"
android:paddingBottom="@dimen/all_apps_header_bottom_padding"
android:orientation="vertical" >
@@ -44,15 +45,5 @@
-
-
-
-
-
\ No newline at end of file
diff --git a/res/layout/search_container_all_apps.xml b/res/layout/search_container_all_apps.xml
index b46298cfdb..db218c3d4b 100644
--- a/res/layout/search_container_all_apps.xml
+++ b/res/layout/search_container_all_apps.xml
@@ -21,7 +21,6 @@
android:layout_centerHorizontal="true"
android:layout_gravity="top|center_horizontal"
android:background="@drawable/bg_all_apps_searchbox"
- android:elevation="1dp"
android:focusableInTouchMode="true"
android:gravity="center"
android:hint="@string/all_apps_search_bar_hint"
diff --git a/res/layout/secondary_launcher.xml b/res/layout/secondary_launcher.xml
index 4be2e456ac..f48f3c0aa4 100644
--- a/res/layout/secondary_launcher.xml
+++ b/res/layout/secondary_launcher.xml
@@ -42,8 +42,7 @@
android:contentDescription="@string/all_apps_button_label"
android:onClick="onAppsButtonClicked" />
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+ android:visibility="invisible" />
\ No newline at end of file
diff --git a/res/values-be/strings.xml b/res/values-be/strings.xml
index 69a16bae5f..6886b7085d 100644
--- a/res/values-be/strings.xml
+++ b/res/values-be/strings.xml
@@ -72,7 +72,7 @@
"Спіс працоўных праграм"
"Выдаліць"
"Дэінсталяваць"
- "Пра праграму"
+ "Звесткі аб праграме"
"Усталяваць"
"Не прапаноўваць праграму"
"Замацаваць прапанаваную праграму"
diff --git a/res/values-te/strings.xml b/res/values-te/strings.xml
index 605278f8e7..7fddcf4da0 100644
--- a/res/values-te/strings.xml
+++ b/res/values-te/strings.xml
@@ -141,7 +141,7 @@
"ఇష్టమైనవిలో %1$sవ స్థానానికి తరలించు"
"అంశం తరలించబడింది"
"ఈ ఫోల్డర్కి జోడించండి: %1$s"
- "%1$s గల ఫోల్డర్కు జోడించు"
+ "%1$s గల ఫోల్డర్కు జోడించండి"
"అంశం ఫోల్డర్కు జోడించబడింది"
"ఈ పేరుతో ఫోల్డర్ను క్రియేట్ చేయండి: %1$s"
"ఫోల్డర్ క్రియేట్ చేయబడింది"
diff --git a/res/values/config.xml b/res/values/config.xml
index d9b3da5b07..4cab2dec09 100644
--- a/res/values/config.xml
+++ b/res/values/config.xml
@@ -49,9 +49,6 @@
popup_container_iterate_children
-
- false
-
diff --git a/res/values/styles.xml b/res/values/styles.xml
index 9e75a31804..7582a30435 100644
--- a/res/values/styles.xml
+++ b/res/values/styles.xml
@@ -20,6 +20,7 @@
-
+
-
+
-
-
-
-
diff --git a/quickstep/src/com/android/launcher3/taskbar/TaskbarViewController.java b/quickstep/src/com/android/launcher3/taskbar/TaskbarViewController.java
index b58b6b5273..168c353273 100644
--- a/quickstep/src/com/android/launcher3/taskbar/TaskbarViewController.java
+++ b/quickstep/src/com/android/launcher3/taskbar/TaskbarViewController.java
@@ -428,8 +428,8 @@ public class TaskbarViewController implements TaskbarControllers.LoggableTaskbar
}
public void onRotationChanged(DeviceProfile deviceProfile) {
- if (mControllers.taskbarStashController.isInApp()) {
- // We only translate on rotation when on home
+ if (!mControllers.uiController.isIconAlignedWithHotseat()) {
+ // We only translate on rotation when icon is aligned with hotseat
return;
}
mActivity.setTaskbarWindowHeight(